from distutils.core import setup

setup(
    name='jetdc-neaster',
    version='1.1.0',
    py_modules=['jetdc-neaster'],
    author='jetdc',
    author_email='jetdc@163.com',
    url='http://www.163.com',
    description='just for test',
    )
